@@ -1,7 +1,9 @@
 package App::YouTubeUtils;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-04-01'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $DIST = 'App-YouTubeUtils'; # DIST
+our $VERSION = '0.004'; # VERSION
 
 1;
 # ABSTRACT: Command-line utilities related to YouTube
@@ -18,7 +20,7 @@ App::YouTubeUtils - Command-line utilities related to YouTube
 
 =head1 VERSION
 
-This document describes version 0.003 of App::YouTubeUtils (from Perl distribution App-YouTubeUtils), released on 2020-04-01.
+This document describes version 0.004 of App::YouTubeUtils (from Perl distribution App-YouTubeUtils), released on 2020-04-01.
 
 =head1 DESCRIPTION
 
